@@ -7,9 +7,10 @@ import os
 import sys
 
 import glib
+
 import gobject
 
-from mopidy import config as config_lib
+from mopidy import config as config_lib, exceptions
 from mopidy.audio import Audio
 from mopidy.core import Core
 from mopidy.utils import deps, process, versioning
@@ -99,7 +100,7 @@ class Command(object):
         self._children[name] = command
 
     def add_argument(self, *args, **kwargs):
-        """Add am argument to the parser.
+        """Add an argument to the parser.
 
         This method takes all the same arguments as the
         :class:`argparse.ArgumentParser` version of this method.
@@ -260,29 +261,70 @@ class RootCommand(Command):
     def run(self, args, config):
         loop = gobject.MainLoop()
 
+        mixer_class = self.get_mixer_class(config, args.registry['mixer'])
         backend_classes = args.registry['backend']
         frontend_classes = args.registry['frontend']
 
         try:
-            audio = self.start_audio(config)
+            mixer = self.start_mixer(config, mixer_class)
+            audio = self.start_audio(config, mixer)
             backends = self.start_backends(config, backend_classes, audio)
-            core = self.start_core(audio, backends)
+            core = self.start_core(mixer, backends)
             self.start_frontends(config, frontend_classes, core)
             loop.run()
+        except (exceptions.BackendError,
+                exceptions.FrontendError,
+                exceptions.MixerError):
+            logger.info('Initialization error. Exiting...')
         except KeyboardInterrupt:
             logger.info('Interrupted. Exiting...')
-            return
         finally:
             loop.quit()
             self.stop_frontends(frontend_classes)
             self.stop_core()
             self.stop_backends(backend_classes)
             self.stop_audio()
+            self.stop_mixer(mixer_class)
             process.stop_remaining_actors()
 
-    def start_audio(self, config):
+    def get_mixer_class(self, config, mixer_classes):
+        logger.debug(
+            'Available Mopidy mixers: %s',
+            ', '.join(m.__name__ for m in mixer_classes) or 'none')
+
+        selected_mixers = [
+            m for m in mixer_classes if m.name == config['audio']['mixer']]
+        if len(selected_mixers) != 1:
+            logger.error(
+                'Did not find unique mixer "%s". Alternatives are: %s',
+                config['audio']['mixer'],
+                ', '.join([m.name for m in mixer_classes]))
+            process.exit_process()
+        return selected_mixers[0]
+
+    def start_mixer(self, config, mixer_class):
+        try:
+            logger.info('Starting Mopidy mixer: %s', mixer_class.__name__)
+            mixer = mixer_class.start(config=config).proxy()
+            self.configure_mixer(config, mixer)
+            return mixer
+        except exceptions.MixerError as exc:
+            logger.error(
+                'Mixer (%s) initialization error: %s',
+                mixer_class.__name__, exc.message)
+            raise
+
+    def configure_mixer(self, config, mixer):
+        volume = config['audio']['mixer_volume']
+        if volume is not None:
+            mixer.set_volume(volume)
+            logger.info('Mixer volume set to %d', volume)
+        else:
+            logger.debug('Mixer volume left unchanged')
+
+    def start_audio(self, config, mixer):
         logger.info('Starting Mopidy audio')
-        return Audio.start(config=config).proxy()
+        return Audio.start(config=config, mixer=mixer).proxy()
 
     def start_backends(self, config, backend_classes, audio):
         logger.info(
@@ -291,14 +333,21 @@ class RootCommand(Command):
 
         backends = []
         for backend_class in backend_classes:
-            backend = backend_class.start(config=config, audio=audio).proxy()
-            backends.append(backend)
+            try:
+                backend = backend_class.start(
+                    config=config, audio=audio).proxy()
+                backends.append(backend)
+            except exceptions.BackendError as exc:
+                logger.error(
+                    'Backend (%s) initialization error: %s',
+                    backend_class.__name__, exc.message)
+                raise
 
         return backends
 
-    def start_core(self, audio, backends):
+    def start_core(self, mixer, backends):
         logger.info('Starting Mopidy core')
-        return Core.start(audio=audio, backends=backends).proxy()
+        return Core.start(mixer=mixer, backends=backends).proxy()
 
     def start_frontends(self, config, frontend_classes, core):
         logger.info(
@@ -306,7 +355,13 @@ class RootCommand(Command):
             ', '.join(f.__name__ for f in frontend_classes) or 'none')
 
         for frontend_class in frontend_classes:
-            frontend_class.start(config=config, core=core)
+            try:
+                frontend_class.start(config=config, core=core)
+            except exceptions.FrontendError as exc:
+                logger.error(
+                    'Frontend (%s) initialization error: %s',
+                    frontend_class.__name__, exc.message)
+                raise
 
     def stop_frontends(self, frontend_classes):
         logger.info('Stopping Mopidy frontends')
@@ -326,6 +381,10 @@ class RootCommand(Command):
         logger.info('Stopping Mopidy audio')
         process.stop_actors_by_class(Audio)
 
+    def stop_mixer(self, mixer_class):
+        logger.info('Stopping Mopidy mixer')
+        process.stop_actors_by_class(mixer_class)
+
 
 class ConfigCommand(Command):
     help = 'Show currently active configuration.'
